//
//  MIT License
//
//  Copyright (c) 2012 TapHarmonic, LLC http://tapharmonic.com/
//
//  Permission is hereby granted, free of charge, to any person obtaining a copy
//  of this software and associated documentation files (the "Software"), to deal
//  in the Software without restriction, including without limitation the rights
//  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
//  copies of the Software, and to permit persons to whom the Software is
//  furnished to do so, subject to the following conditions:
//
//  The above copyright notice and this permission notice shall be included in
//  all copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
//  THE SOFTWARE.
//
//  This project was written by Bob McCune http://bobmccune.com for the 
//  February 2012 CocoaHeads MN meeting.  Accompanying slides can be found here:
//

#import "CocoaHeadsView.h"

void BuildQwarkeePath(CGContextRef context);

@implementation CocoaHeadsView
- (id)initWithFrame:(CGRect)frame {
	self = [super initWithFrame:frame];
	if (self) {
		self.backgroundColor = [UIColor whiteColor];
	}
	return self;
}

- (void)awakeFromNib {
	self.contentMode = UIViewContentModeRedraw;
}

- (void)drawRect:(CGRect)rect {

	CGContextRef context = UIGraphicsGetCurrentContext();
	CGContextSetFillColorWithColor(context, [UIColor blackColor].CGColor);
	CGContextSetStrokeColorWithColor(context, [UIColor blackColor].CGColor);

	CGContextTranslateCTM(context, 10.0f, 40.0f);

	BuildQwarkeePath(context);

	CGContextDrawPath(context, kCGPathFillStroke);

}

/*
 * The following path configuration was produced by a tool called Qwarkee.  Qwarkee
 * will take an SVG file and convert it into a Quartz path.  The code produced is an
 * extremely inefficient way to build such a simple set of subpaths, but I highly 
 * commend its developer as I have found no other solution that can take a raw SVG 
 * file and build Quartz code from it.  You can get a copy of it from the Mac App Store:
 * 
 * http://itunes.apple.com/us/app/qwarkee/id498340809?mt=12
 *
 * Update: PaintCode can import SVG files as well as layered Photoshop Documents.
 * I highly recommend using PaintCode if you're going to be doing any complex Quartz work.
 *
 * http://www.paintcodeapp.com
 */
void BuildQwarkeePath(CGContextRef context) {

	CGContextMoveToPoint(context, 203.287000, 151.698000);
	CGContextAddCurveToPoint(context, 201.252000, 171.379000, 201.255000, 191.445000, 203.290000, 211.113000);
	CGContextAddCurveToPoint(context, 204.943000, 227.093000, 207.281000, 243.032000, 209.880000, 258.885000);
	CGContextAddCurveToPoint(context, 210.923000, 257.049000, 211.966000, 255.212000, 213.009000, 253.375000);
	CGContextAddCurveToPoint(context, 197.662000, 258.646000, 181.533000, 262.126000, 165.554000, 264.760000);
	CGContextAddCurveToPoint(context, 137.403000, 269.399000, 108.566000, 269.626000, 80.456000, 264.561000);
	CGContextAddCurveToPoint(context, 69.480000, 262.583000, 58.131000, 260.080000, 47.792000, 255.760000);
	CGContextAddCurveToPoint(context, 48.834000, 257.597000, 49.877000, 259.434000, 50.920000, 261.270000);
	CGContextAddCurveToPoint(context, 56.672000, 228.694000, 58.482000, 194.873000, 50.718000, 162.460000);
	CGContextAddCurveToPoint(context, 49.372000, 156.844000, 40.735000, 159.226000, 42.079000, 164.842000);
	CGContextAddCurveToPoint(context, 49.454000, 195.629000, 47.747000, 227.937000, 42.282000, 258.889000);
	CGContextAddCurveToPoint(context, 41.814000, 261.540000, 42.987000, 263.386000, 45.410000, 264.399000);
	CGContextAddCurveToPoint(context, 57.468000, 269.435000, 70.806000, 272.106000, 83.639000, 274.142000);
	CGContextAddCurveToPoint(context, 112.787000, 278.767000, 142.156000, 277.861000, 171.187000, 272.849000);
	CGContextAddCurveToPoint(context, 186.068000, 270.281000, 201.083000, 266.927000, 215.390000, 262.014000);
	CGContextAddCurveToPoint(context, 217.888000, 261.156000, 218.934000, 259.035000, 218.519000, 256.504000);
	CGContextAddCurveToPoint(context, 216.012000, 241.214000, 213.773000, 225.851000, 212.179000, 210.438000);
	CGContextAddCurveToPoint(context, 210.168000, 191.006000, 210.235000, 171.139000, 212.246000, 151.698000);
	CGContextAddCurveToPoint(context, 212.497000, 149.265000, 210.017000, 147.219000, 207.767000, 147.219000);
	CGContextAddCurveToPoint(context, 205.135000, 147.219000, 203.539000, 149.271000, 203.287000, 151.698000);
	CGContextAddLineToPoint(context, 203.287000, 151.698000);
	CGContextClosePath(context);


	CGContextMoveToPoint(context, 176.640000, 205.874000);
	CGContextAddCurveToPoint(context, 146.108000, 204.727000, 115.485000, 204.459000, 84.937000, 205.228000);
	CGContextAddCurveToPoint(context, 82.334000, 205.294000, 80.673000, 207.227000, 80.458000, 209.707000);
	CGContextAddCurveToPoint(context, 79.543000, 220.240000, 85.437000, 230.752000, 93.856000, 236.661000);
	CGContextAddCurveToPoint(context, 102.709000, 242.875000, 113.992000, 243.431000, 124.416000, 243.707000);
	CGContextAddCurveToPoint(context, 134.427000, 243.972000, 144.849000, 243.433000, 154.243000, 239.663000);
	CGContextAddCurveToPoint(context, 166.623000, 234.695000, 175.184000, 224.633000, 180.507000, 212.614000);
	CGContextAddCurveToPoint(context, 181.496000, 210.382000, 181.180000, 207.821000, 178.901000, 206.486000);
	CGContextAddCurveToPoint(context, 176.974000, 205.357000, 173.762000, 205.859000, 172.773000, 208.092000);
	CGContextAddCurveToPoint(context, 168.356000, 218.065000, 161.962000, 226.471000, 151.841000, 231.030000);
	CGContextAddCurveToPoint(context, 143.244000, 234.902000, 133.104000, 234.978000, 123.786000, 234.731000);
	CGContextAddCurveToPoint(context, 118.354000, 234.587000, 112.926000, 234.408000, 107.637000, 233.061000);
	CGContextAddCurveToPoint(context, 105.534000, 232.526000, 103.612000, 231.835000, 101.794000, 230.942000);
	CGContextAddCurveToPoint(context, 100.015000, 230.066000, 98.126000, 228.810000, 97.101000, 227.949000);
	CGContextAddCurveToPoint(context, 96.439000, 227.392000, 95.820000, 226.786000, 95.219000, 226.165000);
	CGContextAddCurveToPoint(context, 94.950000, 225.887000, 93.618000, 224.294000, 94.075000, 224.893000);
	CGContextAddCurveToPoint(context, 93.085000, 223.598000, 92.257000, 222.185000, 91.537000, 220.725000);
	CGContextAddCurveToPoint(context, 91.381000, 220.410000, 91.239000, 220.088000, 91.096000, 219.766000);
	CGContextAddCurveToPoint(context, 91.558000, 220.808000, 91.107000, 219.760000, 91.035000, 219.573000);
	CGContextAddCurveToPoint(context, 90.802000, 218.967000, 90.602000, 218.348000, 90.413000, 217.727000);
	CGContextAddCurveToPoint(context, 90.048000, 216.528000, 89.782000, 215.298000, 89.578000, 214.062000);
	CGContextAddCurveToPoint(context, 89.370000, 212.808000, 89.660000, 214.787000, 89.566000, 214.015000);
	CGContextAddCurveToPoint(context, 89.521000, 213.644000, 89.487000, 213.271000, 89.457000, 212.899000);
	CGContextAddCurveToPoint(context, 89.412000, 212.351000, 89.389000, 211.801000, 89.379000, 211.252000);
	CGContextAddCurveToPoint(context, 89.370000, 210.739000, 89.371000, 210.220000, 89.415000, 209.708000);
	CGContextAddCurveToPoint(context, 87.922000, 211.201000, 86.429000, 212.694000, 84.936000, 214.187000);
	CGContextAddCurveToPoint(context, 115.484000, 213.417000, 146.106000, 213.686000, 176.639000, 214.833000);
	CGContextAddCurveToPoint(context, 182.419000, 215.050000, 182.397000, 206.091000, 176.640000, 205.874000);
	CGContextAddLineToPoint(context, 176.640000, 205.874000);
	CGContextClosePath(context);


	CGContextMoveToPoint(context, 112.489000, 144.169000);
	CGContextAddCurveToPoint(context, 108.586000, 149.599000, 106.930000, 157.055000, 105.746000, 163.514000);
	CGContextAddCurveToPoint(context, 104.579000, 169.873000, 103.088000, 178.558000, 106.463000, 184.525000);
	CGContextAddCurveToPoint(context, 110.440000, 191.556000, 118.928000, 192.505000, 126.113000, 191.233000);
	CGContextAddCurveToPoint(context, 133.336000, 189.955000, 140.620000, 186.014000, 145.830000, 180.884000);
	CGContextAddCurveToPoint(context, 149.951000, 176.826000, 143.614000, 170.495000, 139.496000, 174.550000);
	CGContextAddCurveToPoint(context, 135.544000, 178.441000, 130.306000, 181.043000, 124.902000, 182.349000);
	CGContextAddCurveToPoint(context, 122.573000, 182.912000, 119.880000, 183.030000, 117.881000, 182.558000);
	CGContextAddCurveToPoint(context, 115.932000, 182.097000, 114.421000, 180.884000, 114.008000, 179.521000);
	CGContextAddCurveToPoint(context, 113.615000, 178.226000, 113.678000, 178.149000, 113.597000, 177.131000);
	CGContextAddCurveToPoint(context, 113.482000, 175.675000, 113.517000, 174.209000, 113.582000, 172.752000);
	CGContextAddCurveToPoint(context, 113.714000, 169.797000, 114.170000, 166.882000, 114.750000, 163.986000);
	CGContextAddCurveToPoint(context, 115.823000, 158.631000, 117.144000, 152.975000, 120.224000, 148.690000);
	CGContextAddCurveToPoint(context, 121.652000, 146.704000, 120.574000, 143.708000, 118.617000, 142.562000);
	CGContextAddCurveToPoint(context, 116.361000, 141.240000, 113.912000, 142.191000, 112.489000, 144.169000);
	CGContextAddLineToPoint(context, 112.489000, 144.169000);
	CGContextClosePath(context);


	CGContextMoveToPoint(context, 30.602000, 116.895000);
	CGContextAddCurveToPoint(context, 20.464000, 116.606000, 9.381000, 123.652000, 4.217000, 132.147000);
	CGContextAddCurveToPoint(context, 1.334000, 136.890000, 0.810000, 142.533000, 3.379000, 147.513000);
	CGContextAddCurveToPoint(context, 6.670000, 153.892000, 14.422000, 157.091000, 20.865000, 159.072000);
	CGContextAddCurveToPoint(context, 39.380000, 164.760000, 59.762000, 164.456000, 77.519000, 156.442000);
	CGContextAddCurveToPoint(context, 84.787000, 153.162000, 92.115000, 147.170000, 92.036000, 138.497000);
	CGContextAddCurveToPoint(context, 91.948000, 128.823000, 83.663000, 122.162000, 75.381000, 119.051000);
	CGContextAddCurveToPoint(context, 67.902000, 116.242000, 59.006000, 115.510000, 51.060000, 116.255000);
	CGContextAddCurveToPoint(context, 48.630000, 116.483000, 46.581000, 118.120000, 46.581000, 120.734000);
	CGContextAddCurveToPoint(context, 46.581000, 123.003000, 48.625000, 125.441000, 51.060000, 125.213000);
	CGContextAddCurveToPoint(context, 52.519000, 125.076000, 53.991000, 125.046000, 55.456000, 125.034000);
	CGContextAddCurveToPoint(context, 56.942000, 125.022000, 58.429000, 125.068000, 59.913000, 125.148000);
	CGContextAddCurveToPoint(context, 60.774000, 125.195000, 61.634000, 125.266000, 62.493000, 125.346000);
	CGContextAddCurveToPoint(context, 63.874000, 125.475000, 63.979000, 125.500000, 64.969000, 125.655000);
	CGContextAddCurveToPoint(context, 68.937000, 126.275000, 72.796000, 127.357000, 75.939000, 129.045000);
	CGContextAddCurveToPoint(context, 79.121000, 130.754000, 81.529000, 133.170000, 82.628000, 136.338000);
	CGContextAddCurveToPoint(context, 82.774000, 136.759000, 82.878000, 137.193000, 82.982000, 137.627000);
	CGContextAddCurveToPoint(context, 83.296000, 138.954000, 82.947000, 136.784000, 83.060000, 138.094000);
	CGContextAddCurveToPoint(context, 83.094000, 138.493000, 83.083000, 138.893000, 83.071000, 139.293000);
	CGContextAddCurveToPoint(context, 83.033000, 140.564000, 83.266000, 138.408000, 83.034000, 139.641000);
	CGContextAddCurveToPoint(context, 82.963000, 140.017000, 82.849000, 140.385000, 82.736000, 140.750000);
	CGContextAddCurveToPoint(context, 82.368000, 141.938000, 83.140000, 139.970000, 82.602000, 141.100000);
	CGContextAddCurveToPoint(context, 82.435000, 141.453000, 82.231000, 141.788000, 82.029000, 142.121000);
	CGContextAddCurveToPoint(context, 81.888000, 142.346000, 81.741000, 142.565000, 81.587000, 142.781000);
	CGContextAddCurveToPoint(context, 81.886000, 142.412000, 81.870000, 142.430000, 81.538000, 142.834000);
	CGContextAddCurveToPoint(context, 79.213000, 145.646000, 76.211000, 147.258000, 72.531000, 148.918000);
	CGContextAddCurveToPoint(context, 65.480000, 152.101000, 56.681000, 153.757000, 49.066000, 154.094000);
	CGContextAddCurveToPoint(context, 44.218000, 154.309000, 39.308000, 153.650000, 34.528000, 152.917000);
	CGContextAddCurveToPoint(context, 29.519000, 152.148000, 24.528000, 151.037000, 19.776000, 149.256000);
	CGContextAddCurveToPoint(context, 18.675000, 148.844000, 17.157000, 148.131000, 15.651000, 147.260000);
	CGContextAddCurveToPoint(context, 15.003000, 146.885000, 14.380000, 146.469000, 13.770000, 146.033000);
	CGContextAddCurveToPoint(context, 12.807000, 145.346000, 14.473000, 146.615000, 13.594000, 145.887000);
	CGContextAddCurveToPoint(context, 13.263000, 145.614000, 12.951000, 145.319000, 12.643000, 145.020000);
	CGContextAddCurveToPoint(context, 12.386000, 144.771000, 11.159000, 143.273000, 11.985000, 144.366000);
	CGContextAddCurveToPoint(context, 11.658000, 143.933000, 11.377000, 143.468000, 11.116000, 142.992000);
	CGContextAddCurveToPoint(context, 10.567000, 141.991000, 11.337000, 143.814000, 10.877000, 142.427000);
	CGContextAddCurveToPoint(context, 10.732000, 141.991000, 10.470000, 140.111000, 10.648000, 141.722000);
	CGContextAddCurveToPoint(context, 10.596000, 141.247000, 10.598000, 140.767000, 10.617000, 140.290000);
	CGContextAddCurveToPoint(context, 10.663000, 139.155000, 10.382000, 141.281000, 10.683000, 139.811000);
	CGContextAddCurveToPoint(context, 10.782000, 139.328000, 10.927000, 138.855000, 11.084000, 138.389000);
	CGContextAddCurveToPoint(context, 11.178000, 138.109000, 11.534000, 137.253000, 11.000000, 138.519000);
	CGContextAddCurveToPoint(context, 11.134000, 138.203000, 11.287000, 137.894000, 11.441000, 137.588000);
	CGContextAddCurveToPoint(context, 11.926000, 136.629000, 12.528000, 135.732000, 13.171000, 134.873000);
	CGContextAddCurveToPoint(context, 12.328000, 135.998000, 13.498000, 134.523000, 13.728000, 134.266000);
	CGContextAddCurveToPoint(context, 14.177000, 133.763000, 14.654000, 133.286000, 15.140000, 132.819000);
	CGContextAddCurveToPoint(context, 15.564000, 132.410000, 16.008000, 132.022000, 16.456000, 131.640000);
	CGContextAddCurveToPoint(context, 16.683000, 131.447000, 16.914000, 131.261000, 17.146000, 131.074000);
	CGContextAddCurveToPoint(context, 17.963000, 130.417000, 16.346000, 131.674000, 17.189000, 131.047000);
	CGContextAddCurveToPoint(context, 18.232000, 130.270000, 19.331000, 129.568000, 20.456000, 128.917000);
	CGContextAddCurveToPoint(context, 21.481000, 128.324000, 22.543000, 127.798000, 23.625000, 127.319000);
	CGContextAddCurveToPoint(context, 22.353000, 127.882000, 24.104000, 127.143000, 24.425000, 127.026000);
	CGContextAddCurveToPoint(context, 25.036000, 126.803000, 25.657000, 126.611000, 26.283000, 126.434000);
	CGContextAddCurveToPoint(context, 27.133000, 126.193000, 27.999000, 126.013000, 28.872000, 125.875000);
	CGContextAddCurveToPoint(context, 27.332000, 126.117000, 28.815000, 125.900000, 29.174000, 125.875000);
	CGContextAddCurveToPoint(context, 29.650000, 125.841000, 30.127000, 125.841000, 30.603000, 125.854000);
	CGContextAddCurveToPoint(context, 36.382000, 126.018000, 36.366000, 117.059000, 30.602000, 116.895000);
	CGContextAddLineToPoint(context, 30.602000, 116.895000);
	CGContextClosePath(context);


	CGContextMoveToPoint(context, 158.886000, 113.512000);
	CGContextAddCurveToPoint(context, 152.710000, 114.965000, 145.776000, 117.513000, 141.661000, 122.623000);
	CGContextAddCurveToPoint(context, 137.948000, 127.233000, 137.223000, 133.046000, 140.279000, 138.237000);
	CGContextAddCurveToPoint(context, 143.884000, 144.362000, 151.035000, 147.737000, 157.438000, 150.049000);
	CGContextAddCurveToPoint(context, 168.227000, 153.945000, 180.109000, 155.015000, 191.492000, 155.360000);
	CGContextAddCurveToPoint(context, 203.016000, 155.709000, 215.411000, 155.526000, 226.482000, 151.905000);
	CGContextAddCurveToPoint(context, 232.490000, 149.939000, 238.653000, 146.370000, 240.557000, 139.939000);
	CGContextAddCurveToPoint(context, 243.757000, 129.131000, 232.457000, 119.157000, 224.166000, 114.539000);
	CGContextAddCurveToPoint(context, 215.030000, 109.450000, 204.193000, 107.048000, 193.883000, 105.951000);
	CGContextAddCurveToPoint(context, 187.877000, 105.311000, 181.600000, 105.227000, 175.625000, 106.275000);
	CGContextAddCurveToPoint(context, 173.218000, 106.697000, 171.896000, 109.602000, 172.496000, 111.785000);
	CGContextAddCurveToPoint(context, 173.189000, 114.304000, 175.603000, 115.334000, 178.006000, 114.913000);
	CGContextAddCurveToPoint(context, 179.415000, 114.666000, 177.006000, 115.016000, 178.510000, 114.845000);
	CGContextAddCurveToPoint(context, 180.083000, 114.666000, 181.666000, 114.575000, 183.249000, 114.519000);
	CGContextAddCurveToPoint(context, 188.387000, 114.338000, 193.555000, 114.710000, 198.621000, 115.567000);
	CGContextAddCurveToPoint(context, 207.504000, 117.070000, 216.719000, 119.726000, 224.073000, 125.118000);
	CGContextAddCurveToPoint(context, 224.257000, 125.252000, 225.109000, 125.919000, 224.159000, 125.175000);
	CGContextAddCurveToPoint(context, 224.404000, 125.367000, 224.644000, 125.564000, 224.885000, 125.762000);
	CGContextAddCurveToPoint(context, 225.363000, 126.155000, 225.825000, 126.565000, 226.282000, 126.981000);
	CGContextAddCurveToPoint(context, 227.247000, 127.859000, 228.151000, 128.803000, 229.003000, 129.793000);
	CGContextAddCurveToPoint(context, 229.193000, 130.015000, 229.376000, 130.242000, 229.560000, 130.469000);
	CGContextAddCurveToPoint(context, 228.770000, 129.490000, 229.402000, 130.267000, 229.554000, 130.476000);
	CGContextAddCurveToPoint(context, 229.884000, 130.926000, 230.190000, 131.393000, 230.486000, 131.867000);
	CGContextAddCurveToPoint(context, 230.771000, 132.324000, 231.028000, 132.798000, 231.272000, 133.277000);
	CGContextAddCurveToPoint(context, 231.955000, 134.614000, 231.133000, 132.716000, 231.619000, 134.102000);
	CGContextAddCurveToPoint(context, 231.782000, 134.567000, 231.905000, 135.044000, 232.012000, 135.524000);
	CGContextAddCurveToPoint(context, 232.262000, 136.649000, 231.980000, 134.501000, 232.067000, 135.982000);
	CGContextAddCurveToPoint(context, 232.094000, 136.448000, 232.069000, 136.914000, 232.025000, 137.378000);
	CGContextAddCurveToPoint(context, 232.178000, 135.767000, 231.929000, 137.551000, 231.780000, 138.008000);
	CGContextAddCurveToPoint(context, 231.501000, 138.862000, 232.248000, 136.998000, 231.870000, 137.826000);
	CGContextAddCurveToPoint(context, 231.767000, 138.050000, 231.646000, 138.265000, 231.526000, 138.480000);
	CGContextAddCurveToPoint(context, 231.401000, 138.701000, 231.259000, 138.912000, 231.117000, 139.123000);
	CGContextAddCurveToPoint(context, 230.588000, 139.910000, 231.793000, 138.308000, 231.169000, 139.055000);
	CGContextAddCurveToPoint(context, 230.804000, 139.493000, 230.390000, 139.887000, 229.967000, 140.267000);
	CGContextAddCurveToPoint(context, 229.793000, 140.423000, 228.967000, 141.054000, 229.911000, 140.341000);
	CGContextAddCurveToPoint(context, 229.559000, 140.607000, 229.188000, 140.848000, 228.817000, 141.086000);
	CGContextAddCurveToPoint(context, 225.878000, 142.967000, 223.188000, 143.701000, 219.255000, 144.586000);
	CGContextAddCurveToPoint(context, 213.890000, 145.792000, 208.369000, 146.174000, 202.886000, 146.376000);
	CGContextAddCurveToPoint(context, 190.446000, 146.836000, 177.683000, 146.244000, 165.574000, 143.163000);
	CGContextAddCurveToPoint(context, 161.389000, 142.098000, 157.970000, 140.912000, 154.513000, 139.076000);
	CGContextAddCurveToPoint(context, 153.802000, 138.698000, 153.111000, 138.284000, 152.429000, 137.855000);
	CGContextAddCurveToPoint(context, 152.137000, 137.671000, 150.408000, 136.429000, 151.237000, 137.071000);
	CGContextAddCurveToPoint(context, 150.144000, 136.224000, 149.149000, 135.255000, 148.276000, 134.183000);
	CGContextAddCurveToPoint(context, 149.126000, 135.225000, 148.060000, 133.793000, 147.880000, 133.487000);
	CGContextAddCurveToPoint(context, 147.747000, 133.262000, 147.631000, 133.028000, 147.515000, 132.794000);
	CGContextAddCurveToPoint(context, 147.097000, 131.951000, 147.902000, 133.802000, 147.578000, 132.937000);
	CGContextAddCurveToPoint(context, 147.409000, 132.486000, 147.295000, 132.017000, 147.203000, 131.545000);
	CGContextAddCurveToPoint(context, 147.029000, 130.657000, 147.319000, 132.705000, 147.250000, 131.810000);
	CGContextAddCurveToPoint(context, 147.227000, 131.503000, 147.234000, 131.195000, 147.247000, 130.889000);
	CGContextAddCurveToPoint(context, 147.292000, 129.775000, 146.984000, 131.911000, 147.341000, 130.484000);
	CGContextAddCurveToPoint(context, 147.399000, 130.255000, 147.475000, 130.032000, 147.551000, 129.810000);
	CGContextAddCurveToPoint(context, 147.842000, 128.957000, 147.085000, 130.820000, 147.472000, 129.993000);
	CGContextAddCurveToPoint(context, 147.685000, 129.537000, 147.951000, 129.108000, 148.230000, 128.690000);
	CGContextAddCurveToPoint(context, 148.388000, 128.453000, 148.979000, 127.740000, 148.166000, 128.751000);
	CGContextAddCurveToPoint(context, 148.397000, 128.463000, 148.651000, 128.193000, 148.906000, 127.926000);
	CGContextAddCurveToPoint(context, 149.243000, 127.572000, 149.608000, 127.247000, 149.976000, 126.927000);
	CGContextAddCurveToPoint(context, 150.927000, 126.103000, 149.498000, 127.233000, 150.566000, 126.483000);
	CGContextAddCurveToPoint(context, 151.514000, 125.817000, 152.532000, 125.252000, 153.565000, 124.729000);
	CGContextAddCurveToPoint(context, 153.792000, 124.614000, 155.471000, 123.866000, 154.593000, 124.232000);
	CGContextAddCurveToPoint(context, 155.225000, 123.969000, 155.867000, 123.736000, 156.512000, 123.508000);
	CGContextAddCurveToPoint(context, 158.068000, 122.960000, 159.663000, 122.530000, 161.268000, 122.154000);
	CGContextAddCurveToPoint(context, 166.890000, 120.828000, 164.504000, 112.190000, 158.886000, 113.512000);
	CGContextAddLineToPoint(context, 158.886000, 113.512000);
	CGContextClosePath(context);


	CGContextMoveToPoint(context, 142.102000, 104.584000);
	CGContextAddCurveToPoint(context, 129.861000, 103.180000, 117.333000, 103.118000, 105.060000, 103.990000);
	CGContextAddCurveToPoint(context, 98.490000, 104.457000, 91.916000, 105.042000, 85.396000, 105.983000);
	CGContextAddCurveToPoint(context, 84.030000, 106.180000, 82.515000, 106.306000, 81.205000, 106.783000);
	CGContextAddCurveToPoint(context, 75.824000, 108.746000, 78.147000, 117.406000, 83.587000, 115.422000);
	CGContextAddCurveToPoint(context, 84.797000, 114.980000, 86.187000, 114.861000, 87.449000, 114.670000);
	CGContextAddCurveToPoint(context, 87.794000, 114.617000, 88.140000, 114.569000, 88.486000, 114.520000);
	CGContextAddCurveToPoint(context, 87.377000, 114.676000, 89.200000, 114.431000, 89.383000, 114.408000);
	CGContextAddCurveToPoint(context, 90.635000, 114.252000, 91.889000, 114.116000, 93.144000, 113.984000);
	CGContextAddCurveToPoint(context, 97.109000, 113.566000, 101.084000, 113.246000, 105.060000, 112.948000);
	CGContextAddCurveToPoint(context, 117.319000, 112.031000, 129.874000, 112.139000, 142.102000, 113.542000);
	CGContextAddCurveToPoint(context, 144.533000, 113.821000, 146.581000, 111.293000, 146.581000, 109.063000);
	CGContextAddCurveToPoint(context, 146.581000, 106.411000, 144.526000, 104.863000, 142.102000, 104.584000);
	CGContextAddLineToPoint(context, 142.102000, 104.584000);
	CGContextClosePath(context);


	CGContextMoveToPoint(context, 157.656000, 21.120000);
	CGContextAddCurveToPoint(context, 163.766000, 22.579000, 166.375000, 26.690000, 167.418000, 32.543000);
	CGContextAddCurveToPoint(context, 167.747000, 34.387000, 167.601000, 38.414000, 167.307000, 40.100000);
	CGContextAddCurveToPoint(context, 167.078000, 41.413000, 166.727000, 42.702000, 166.296000, 43.962000);
	CGContextAddCurveToPoint(context, 165.722000, 45.641000, 166.630000, 43.018000, 165.707000, 45.437000);
	CGContextAddCurveToPoint(context, 165.345000, 46.388000, 164.973000, 47.335000, 164.569000, 48.270000);
	CGContextAddCurveToPoint(context, 161.683000, 54.944000, 157.750000, 61.274000, 157.029000, 68.647000);
	CGContextAddCurveToPoint(context, 156.196000, 77.176000, 162.276000, 84.476000, 168.136000, 89.847000);
	CGContextAddCurveToPoint(context, 172.489000, 93.835000, 178.994000, 87.365000, 174.624000, 83.360000);
	CGContextAddCurveToPoint(context, 171.717000, 80.696000, 168.391000, 77.465000, 166.967000, 73.902000);
	CGContextAddCurveToPoint(context, 165.829000, 71.056000, 165.974000, 69.089000, 166.661000, 66.451000);
	CGContextAddCurveToPoint(context, 168.445000, 59.613000, 172.746000, 52.984000, 175.141000, 46.401000);
	CGContextAddCurveToPoint(context, 179.950000, 33.189000, 174.901000, 15.810000, 160.094000, 12.273000);
	CGContextAddCurveToPoint(context, 154.344000, 10.899000, 151.903000, 19.746000, 157.656000, 21.120000);
	CGContextAddLineToPoint(context, 157.656000, 21.120000);
	CGContextClosePath(context);


	CGContextMoveToPoint(context, 105.760000, 19.040000);
	CGContextAddCurveToPoint(context, 111.870000, 20.499000, 114.479000, 24.610000, 115.522000, 30.463000);
	CGContextAddCurveToPoint(context, 115.851000, 32.307000, 115.704000, 36.334000, 115.410000, 38.019000);
	CGContextAddCurveToPoint(context, 115.181000, 39.332000, 114.831000, 40.622000, 114.400000, 41.882000);
	CGContextAddCurveToPoint(context, 113.826000, 43.561000, 114.734000, 40.939000, 113.812000, 43.358000);
	CGContextAddCurveToPoint(context, 113.449000, 44.309000, 113.078000, 45.255000, 112.674000, 46.190000);
	CGContextAddCurveToPoint(context, 109.789000, 52.864000, 105.854000, 59.193000, 105.133000, 66.566000);
	CGContextAddCurveToPoint(context, 104.299000, 75.096000, 110.380000, 82.397000, 116.242000, 87.768000);
	CGContextAddCurveToPoint(context, 120.594000, 91.756000, 127.100000, 85.286000, 122.729000, 81.281000);
	CGContextAddCurveToPoint(context, 119.822000, 78.617000, 116.494000, 75.385000, 115.070000, 71.822000);
	CGContextAddCurveToPoint(context, 113.933000, 68.976000, 114.077000, 67.009000, 114.766000, 64.370000);
	CGContextAddCurveToPoint(context, 116.551000, 57.533000, 120.851000, 50.904000, 123.246000, 44.321000);
	CGContextAddCurveToPoint(context, 128.053000, 31.109000, 123.006000, 13.731000, 108.197000, 10.193000);
	CGContextAddCurveToPoint(context, 102.447000, 8.819000, 100.006000, 17.666000, 105.760000, 19.040000);
	CGContextAddLineToPoint(context, 105.760000, 19.040000);
	CGContextClosePath(context);


	CGContextMoveToPoint(context, 56.991000, 19.457000);
	CGContextAddCurveToPoint(context, 63.100000, 20.916000, 65.709000, 25.027000, 66.752000, 30.880000);
	CGContextAddCurveToPoint(context, 67.081000, 32.724000, 66.934000, 36.751000, 66.640000, 38.437000);
	CGContextAddCurveToPoint(context, 66.411000, 39.750000, 66.060000, 41.040000, 65.629000, 42.300000);
	CGContextAddCurveToPoint(context, 65.055000, 43.979000, 65.963000, 41.358000, 65.041000, 43.776000);
	CGContextAddCurveToPoint(context, 64.678000, 44.727000, 64.307000, 45.673000, 63.903000, 46.608000);
	CGContextAddCurveToPoint(context, 61.018000, 53.282000, 57.083000, 59.611000, 56.362000, 66.985000);
	CGContextAddCurveToPoint(context, 55.529000, 75.515000, 61.610000, 82.815000, 67.472000, 88.186000);
	CGContextAddCurveToPoint(context, 71.824000, 92.174000, 78.330000, 85.704000, 73.959000, 81.699000);
	CGContextAddCurveToPoint(context, 71.052000, 79.035000, 67.724000, 75.804000, 66.300000, 72.241000);
	CGContextAddCurveToPoint(context, 65.162000, 69.395000, 65.306000, 67.428000, 65.995000, 64.789000);
	CGContextAddCurveToPoint(context, 67.780000, 57.952000, 72.080000, 51.323000, 74.476000, 44.740000);
	CGContextAddCurveToPoint(context, 79.283000, 31.528000, 74.237000, 14.148000, 59.429000, 10.611000);
	CGContextAddCurveToPoint(context, 53.678000, 9.236000, 51.237000, 18.083000, 56.991000, 19.457000);
	CGContextAddLineToPoint(context, 56.991000, 19.457000);
	CGContextClosePath(context);


	CGContextMoveToPoint(context, 254.731000, 126.895000);
	CGContextAddCurveToPoint(context, 262.577000, 122.392000, 271.802000, 121.951000, 278.685000, 127.690000);
	CGContextAddCurveToPoint(context, 286.831000, 134.484000, 288.614000, 145.799000, 287.459000, 155.811000);
	CGContextAddCurveToPoint(context, 285.355000, 174.051000, 263.389000, 181.988000, 248.051000, 187.096000);
	CGContextAddCurveToPoint(context, 242.207000, 189.042000, 236.285000, 190.773000, 230.518000, 192.943000);
	CGContextAddCurveToPoint(context, 228.235000, 193.802000, 226.697000, 195.936000, 227.389000, 198.453000);
	CGContextAddCurveToPoint(context, 227.993000, 200.645000, 230.612000, 202.442000, 232.899000, 201.582000);
	CGContextAddCurveToPoint(context, 250.337000, 195.021000, 269.442000, 191.391000, 283.971000, 178.932000);
	CGContextAddCurveToPoint(context, 291.808000, 172.211000, 295.993000, 163.109000, 296.678000, 152.894000);
	CGContextAddCurveToPoint(context, 297.423000, 141.772000, 294.061000, 129.916000, 285.843000, 122.092000);
	CGContextAddCurveToPoint(context, 275.962000, 112.684000, 261.632000, 112.605000, 250.209000, 119.161000);
	CGContextAddCurveToPoint(context, 245.202000, 122.034000, 249.713000, 129.775000, 254.731000, 126.895000);
	CGContextAddLineToPoint(context, 254.731000, 126.895000);
	CGContextClosePath(context);
}

@end